from setuptools import setup
setup(
    name="Goosu",
    version='0.0',
    install_requires = ['requests',
                        'json',],
    author_email='Leha.metlushko@bk.ru',
    url='https://github.com/Qquiqlerr/Goosu',
    download_url = 'https://github.com/Qquiqlerr/Goosu.git',
    packages=['Goosu'],

)
